
### Replication script for: 
### "Do Public Consultations Reduce Blame Attribution?: The Impact of Consultation Characteristics, Gender, and Gender Attitudes"
### Anthony Kevins and Barbara Vis
### Political Behavior

## User guide:
# Ensure all required packages are installed (in RStudio you should be prompted to install missing packages)
# Press Ctrl-Shift-S in RStudio to run this script
# Note: the script and data files should be in the same folder; after running the script, all figures and tables will be in that folder

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(tidyverse)
library(effects)
library(stargazer)
library(ggthemes)
library(ggeffects)
library(grid)
library(gridExtra)
library(ggpubr)
library(scales)
library(htmltools)
library(kableExtra)
library(systemfit)
library(multcomp)
library(table1)
library(pwr)
library(psych)
library(mlogit)

# Read data files
blame <- read_csv("blame.csv")
blame_2 <- read_csv("blame_2.csv")

# Colour scheme
ext_538 <- c("#008FD5", "#FF2700", "#A44C9B", "#FEBC00")

### Data set prep

## Study 1

# Convert numeric variables to factor

blame <- blame %>%
  mutate(consultation = factor(consultation,
    levels = 1:3,
    labels = c(
      "Control",
      "Listen/Explain",
      "Listen/Explain/Align"
    )
  ))

blame <- blame %>%
  mutate(pro_policy = factor(pro_policy,
    levels = 0:1,
    labels = c(
      "Anti-Policy",
      "Pro-Policy"
    )
  ))
blame <- blame %>%
  mutate(female_politician = factor(female_politician,
    levels = 0:1,
    labels = c(
      "Male Politician",
      "Female Politician"
    )
  ))

blame <- blame %>%
  mutate(co_partisan = factor(co_partisan,
    levels = 0:1,
    labels = c(
      "Opposing Partisan",
      "Co-Partisan"
    )
  ))
blame <- blame %>%
  mutate(gender_check = factor(gender_check,
    levels = 0:1,
    labels = c(
      "Failed",
      "Passed"
    )
  ))

blame <- blame %>%
  mutate(party_check = factor(party_check,
    levels = 0:1,
    labels = c(
      "Failed",
      "Passed"
    )
  ))

## Study 2

# Convert numeric variables to factor

blame_2 <- blame_2 %>%
  mutate(consultation = factor(consultation,
    levels = 1:3,
    labels = c(
      "Control",
      "Listen/Explain",
      "Listen/Explain/Align"
    )
  ))

blame_2 <- blame_2 %>%
  mutate(pro_policy = factor(pro_policy,
    levels = 0:1,
    labels = c(
      "Anti-Policy",
      "Pro-Policy"
    )
  ))

blame_2 <- blame_2 %>%
  mutate(pro_policy_full = factor(pro_policy_full,
    levels = 0:2,
    labels = c(
      "No Stance",
      "Pro-Policy",
      "Anti-Policy"
    )
  ))
blame_2 <- blame_2 %>%
  mutate(female_politician = factor(female_politician,
    levels = 0:1,
    labels = c(
      "Male Politician",
      "Female Politician"
    )
  ))

blame_2 <- blame_2 %>%
  mutate(wall = factor(wall,
    levels = 0:1,
    labels = c(
      "Changing Course",
      "Pushing Forward"
    )
  ))
blame_2 <- blame_2 %>%
  mutate(gender_check = factor(gender_check,
    levels = 0:1,
    labels = c(
      "Failed",
      "Passed"
    )
  ))

# Generate outcome favourability variable for follow-up analysis
blame_2 <- blame_2 %>%
  mutate(stance = factor(stance,
    levels = 1:3,
    labels = c(
      "Wall",
      "Levee",
      "Don't Know"
    )
  ))

blame_2 <- blame_2 %>%
  mutate(
    preferred_outcome =
      case_when(
        (stance == "Wall" & wall == "Changing Course") |
          (stance == "Levee" & wall == "Pushing Forward") ~ 1,
        stance == "Don't Know" ~ 2,
        (stance == "Wall" & wall == "Pushing Forward") |
          (stance == "Levee" & wall == "Changing Course") ~ 3
      )
  )

blame_2 <- blame_2 %>%
  mutate(preferred_outcome = factor(preferred_outcome,
    levels = 1:3,
    labels = c(
      "Disfavoured Outcome",
      "No Preference",
      "Favoured Outcome"
    )
  ))

## Study 1 Analysis

## Figure 1

model2 <- lm(mayor_blame ~ responsiveness * consultation,
  na.action = na.omit,
  data = blame
)

predictions <- ggpredict(model2,
  terms = c(
    "responsiveness",
    "consultation[Control, Listen/Explain, Listen/Explain/Align]"
  ),
  ci.lvl = 0.835
)


p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed", "dotted")) +
  scale_colour_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  labs(
    title = "Panel A: Perceived Responsiveness",
    x = "Perceived Responsiveness",
    y = "Blame Attribution",
    colour = "Treatment",
    linetype = "Treatment",
    fill = "Treatment"
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(ylim = c(2.5, 5))



model3 <- lm(mayor_blame ~ decision_acceptance * consultation,
  na.action = na.omit,
  data = blame
)

predictions <- ggpredict(model3,
  terms = c(
    "decision_acceptance",
    "consultation[Control, Listen/Explain, Listen/Explain/Align]]"
  ),
  ci.lvl = 0.835
)

p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("dotted", "dashed", "dotted")) +
  scale_colour_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  labs(
    title = "Panel B: Decision Acceptance",
    x = "Decision Acceptance",
    y = "Blame Attribution",
    colour = "Treatment",
    linetype = "Treatment",
    fill = "Treatment"
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(ylim = c(2.5, 5))

Figure_1 <- ggarrange(p1, p2, nrow = 1, common.legend = TRUE, legend = "bottom")
ggsave(file = "Figure 1.png", Figure_1, width = 9, height = 4)


# OA4 Figure 1

# Regression
model4 <- lm(mayor_blame ~ pro_policy * consultation,
  na.action = na.omit,
  data = blame
)

# Generate by group means and confidence intervals
eff0 <- effect("pro_policy * consultation", model4, typical = "mean", se = c(level = .835))
eff0r <- cbind(eff0$x, fit = eff0$fit, lower = eff0$lower, higher = eff0$upper)
eff0r <- eff0r[order(eff0r$pro_policy, eff0r$consultation), ]
rownames(eff0r) <- NULL
eff0r$treat <- as.numeric(rownames(eff0r))
eff0r$consultation <- factor(x = eff0r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff0r$pro_policy <- factor(x = eff0r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff0r <- eff0r[with(eff0r, order(pro_policy, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model4)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(pro_policy, ref = "Pro-Policy")
* consultation,
na.action = na.omit,
data = blame
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signif <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph
Pro_or_Anti_Policy_1 <- ggplot(eff0r, aes(
  x = consultation,
  y = fit,
  position = pro_policy, colour = pro_policy, shape = pro_policy
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  scale_y_continuous(breaks = c(3, 3.4, 3.8, 4.2)) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave(file = "OA4 Figure 1.png", Pro_or_Anti_Policy_1, width = 5, height = 5)


# OA4 Figure 2

# Regression
model5 <- lm(mayor_blame ~ co_partisan * consultation,
  na.action = na.omit,
  data = blame
)

# Generate by group means and confidence intervals
eff0 <- effect("co_partisan * consultation", model5, typical = "mean", se = c(level = .835))
eff0r <- cbind(eff0$x, fit = eff0$fit, lower = eff0$lower, higher = eff0$upper)
eff0r <- eff0r[order(eff0r$co_partisan, eff0r$consultation), ]
rownames(eff0r) <- NULL
eff0r$treat <- as.numeric(rownames(eff0r))
eff0r$consultation <- factor(x = eff0r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff0r$co_partisan <- factor(x = eff0r$co_partisan, levels = c(
  "Opposing Partisan",
  "Co-Partisan"
))
eff0r <- eff0r[with(eff0r, order(co_partisan, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model5)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(co_partisan, ref = "Co-Partisan")
* consultation,
na.action = na.omit,
data = blame
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signif <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph
ggplot(eff0r, aes(
  x = consultation,
  y = fit,
  position = co_partisan, colour = co_partisan, shape = co_partisan
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave("OA4 Figure 2.png", width = 5, height = 5)


## Figure 2

model1 <- lm(mayor_blame ~ consultation,
  na.action = na.omit,
  data = blame
)

eff1 <- effect("consultation", model1, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))

# Extract by-group significance levels (comparison with control group mean)
p.values <- summary(model1)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif[c(1)] <- "' '" # Delete intercept coefficients

# Graph
figure_2 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), shape = 18, colour = ext_538[1]) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, hjust = -0.15, colour = ext_538[1], show.legend = FALSE, parse = TRUE
  ) +
  labs(title = "Panel A: Overall Effects", x = "\nConsultation", y = "Blame Attribution") +
  scale_colour_manual(values = ext_538[1]) +
  scale_y_continuous(limits = c(3.5, 3.91)) +
  theme(legend.title = element_blank()) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))


# Regression
model6 <- lm(mayor_blame ~ female_politician * consultation,
  na.action = na.omit,
  data = blame
)

# Generate by group means and confidence intervals
eff6 <- effect("female_politician * consultation", model6, typical = "mean", se = c(level = .835))
eff6r <- cbind(eff6$x, fit = eff6$fit, lower = eff6$lower, higher = eff6$upper)
eff6r <- eff6r[order(eff6r$female_politician, eff6r$consultation), ]
rownames(eff6r) <- NULL
eff6r$treat <- as.numeric(rownames(eff6r))
eff6r$consultation <- factor(x = eff6r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff6r$female_politician <- factor(x = eff6r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff6r <- eff6r[with(eff6r, order(female_politician, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model6)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(female_politician, ref = "Female Politician")
* consultation,
na.action = na.omit,
data = blame
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signifa <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signifa[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph
figure_2a <- ggplot(eff6r, aes(
  x = consultation,
  y = fit,
  position = female_politician, colour = female_politician, shape = female_politician
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifa)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel B: Gender Effects", x = "\nConsultation", y = "Blame Attribution") +
  scale_y_continuous(limits = c(3.5, 3.91)) +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(
    legend.position = c(.99, .925),
    legend.justification = c("right", "top"),
    legend.box.just = "right",
    legend.margin = margin(1, 1, 1, 1),
    legend.spacing.y = unit(0, "mm"),
    panel.border = element_rect(colour = "grey", fill = NA),
    legend.title = element_text(size = 10),
    legend.background = element_blank(),
    legend.box.background = element_rect(colour = "grey"),
    strip.background = element_rect(fill = ggplot2::alpha(ext_538[1], .025))
  )

Figure_2 <- ggarrange(figure_2, figure_2a, nrow = 1)
ggsave(file = "Figure 2.png", Figure_2, width = 9, height = 4)


## Figure 3

# Regression
model6b <- lm(mayor_blame ~ female_politician * sexism * consultation,
  na.action = na.omit,
  data = blame
)

xrange <- quantile(blame$sexism, probs = c(.05, .95))


# Control-Consultation Comparisons
predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Control]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Control` = ""))
p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Control Group",
    x = "Sexism",
    y = "Blame Attribution",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(3, 4.5))

predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Listen/Explain]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Listen/Explain` = ""))
p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Listen/Explain Treatment",
    x = "Sexism",
    y = " ",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(3, 4.5))


predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Listen/Explain/Align]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Listen/Explain/Align` = ""))
p3 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Listen/Explain/Align Treatment",
    x = "Sexism",
    y = " ",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(3, 4.5))


figure_3 <- ggarrange(p1, p2, p3, nrow = 1)

ggsave(file = "Figure 3.png", figure_3, width = 10, height = 4)


# OA4 Figure 3

r1 <- mayor_blame_drop ~ consultation
r2 <- mayor_blame_death ~ consultation

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame
)
summary(fitsur)

restriction <- "rdrop_(Intercept)- rdeath_(Intercept)"
linearHypothesis(fitsur, restriction, test = "Chisq")

t.test(blame$mayor_blame_drop, blame$mayor_blame_death)
mean(blame$mayor_blame_drop)
mean(blame$mayor_blame_death)


model7a <- lm(mayor_blame_drop ~ consultation,
  na.action = na.omit,
  data = blame
)

eff1 <- effect("consultation", model7a, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$group <- "Drop in Beds"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model7a)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients



model7b <- lm(mayor_blame_death ~ consultation,
  na.action = na.omit,
  data = blame
)

eff2 <- effect("consultation", model7b, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model7b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients

# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signif <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)


ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave("OA4 Figure 3.png", width = 5, height = 5)



# OA4 Figure 4

r1 <- mayor_blame_drop ~ consultation * pro_policy
r2 <- mayor_blame_death ~ consultation * pro_policy

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame
)
summary(fitsur)

restriction <- "rdrop_pro_policyPro-Policy- rdeath_pro_policyPro-Policy"
linearHypothesis(fitsur, restriction, test = "Chisq")


model8a <- lm(mayor_blame_drop ~ consultation * pro_policy,
  na.action = na.omit,
  data = blame
)

eff1 <- effect("consultation * pro_policy", model8a, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$pro_policy <- factor(x = eff1r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff1r$group <- "Drop in Beds"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model8a)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_drop ~ consultation * relevel(pro_policy, ref = "Pro-Policy"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values1 <- c(p.values1, p.valuesalt)
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif1[c(1, 4)] <- "' '" # Delete intercept coefficients


model8b <- lm(mayor_blame_death ~ consultation * pro_policy,
  na.action = na.omit,
  data = blame
)

eff2 <- effect("consultation * pro_policy", model8b, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$pro_policy <- factor(x = eff2r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model8b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_death ~ consultation * relevel(pro_policy, ref = "Pro-Policy"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values2 <- c(p.values2, p.valuesalt)
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif2[c(1, 4)] <- "' '" # Delete intercept coefficients


# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signifa <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)


p1 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifa)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel A: Policy Stance", x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  facet_grid(~pro_policy) +
  scale_y_continuous(limits = c(2.75, 4.4),
                     breaks = c(2.8, 3.2, 3.6, 4, 4.4)) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))



# Graph

r1 <- mayor_blame_drop ~ consultation * co_partisan
r2 <- mayor_blame_death ~ consultation * co_partisan

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame
)
summary(fitsur)

restriction <- "rdrop_co_partisanCo-Partisan- rdeath_co_partisanCo-Partisan"
linearHypothesis(fitsur, restriction, test = "Chisq")

# Graph

model8b <- lm(mayor_blame_drop ~ consultation * co_partisan,
  na.action = na.omit,
  data = blame
)

eff1 <- effect("consultation * co_partisan", model8b, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$co_partisan <- factor(x = eff1r$co_partisan, levels = c(
  "Opposing Partisan",
  "Co-Partisan"
))
eff1r$group <- "Drop in Beds"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model8b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_drop ~ consultation * relevel(co_partisan, ref = "Co-Partisan"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values1 <- c(p.values1, p.valuesalt)
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif1[c(1, 4)] <- "' '" # Delete intercept coefficients


model8b <- lm(mayor_blame_death ~ consultation * co_partisan,
  na.action = na.omit,
  data = blame
)

eff2 <- effect("consultation * co_partisan", model8b, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$co_partisan <- factor(x = eff2r$co_partisan, levels = c(
  "Opposing Partisan",
  "Co-Partisan"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model8b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_death ~ consultation * relevel(co_partisan, ref = "Co-Partisan"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values2 <- c(p.values2, p.valuesalt)
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif2[c(1, 4)] <- "' '" # Delete intercept coefficients


# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signifb <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)


p2 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifb)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel B: Partisanship", x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  facet_grid(~co_partisan) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))



# Figure 8c

r1 <- mayor_blame_drop ~ consultation * female_politician
r2 <- mayor_blame_death ~ consultation * female_politician

blame_simple_labels <- read_csv("blame.csv")

blame_simple_labels <- blame_simple_labels %>%
  mutate(female_politician = factor(female_politician,
    levels = 0:1,
    labels = c(
      "Male",
      "Female"
    )
  ))

blame_simple_labels <- blame_simple_labels %>%
  mutate(consultation = factor(consultation, levels = 1:3))

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame_simple_labels
)
summary(fitsur)

restriction <- "rdrop_female_politicianFemale- rdeath_female_politicianFemale"
linearHypothesis(fitsur, restriction, test = "Chisq")


# Graph

model8c <- lm(mayor_blame_drop ~ consultation * female_politician,
  na.action = na.omit,
  data = blame
)

eff1 <- effect("consultation * female_politician", model8c, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$female_politician <- factor(x = eff1r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff1r$group <- "Drop in Beds"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model8c)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_drop ~ consultation * relevel(female_politician, ref = "Female Politician"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values1 <- c(p.values1, p.valuesalt)
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif1[c(1, 4)] <- "' '" # Delete intercept coefficients


model8c <- lm(mayor_blame_death ~ consultation * female_politician,
  na.action = na.omit,
  data = blame
)

eff2 <- effect("consultation * female_politician", model8c, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$female_politician <- factor(x = eff2r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model8c)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_death ~ consultation * relevel(female_politician, ref = "Female Politician"),
  na.action = na.omit,
  data = blame
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values2 <- c(p.values2, p.valuesalt)
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif2[c(1, 4)] <- "' '" # Delete intercept coefficients


# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signifc <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)

p3 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifc)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel C: Politician Gender", x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  facet_grid(~female_politician) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))


# Combine panels

Online_Appendix <- ggarrange(p1, p2, p3, nrow = 3, common.legend = TRUE, legend = "bottom")
ggsave(file = "OA4 Figure 4.png", Online_Appendix, width = 9, height = 10)


# Figure 8d

r1 <- mayor_blame_drop ~ consultation * sexism * female_politician
r2 <- mayor_blame_death ~ consultation * sexism * female_politician

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame_simple_labels
)
summary(fitsur)

restriction <- "rdrop_sexism- rdeath_sexism"
linearHypothesis(fitsur, restriction, test = "Chisq")


## Create tables

stargazer(model1, model6, model6b,
  dep.var.labels = c("Blame Attributed to Mayor"),
  single.row = TRUE, no.space = TRUE,
  order = c(3, 4, 1, 6, 7),
  covariate.labels = c(
    "<b>Consultation (baseline: None)</b> <br> Listen and Explain",
    "Listen, Explain, and Align", "Female Politician",
    "Female Politician * Listen and Explain", "Female Politician * Listen, Explain, and Align",
    "Sexism", "Sexism * Female Politician",
    "Sexism * Listen and Explain", "Sexism * Listen, Explain, and Align",
    "Sexism * Female Politician * Listen and Explain", "Sexism * Female Politician * Listen, Explain, and Align"
  ),
  star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
  notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
  type = "html", out = "OA2 Table 1.htm"
)


stargazer(model2, model3,
  dep.var.labels = c("Blame Attributed to Mayor"),
  single.row = TRUE, no.space = TRUE,
  order = c(3, 4, 1, 2),
  covariate.labels = c(
    "<b>Consultation (baseline: None)</b> <br> Listen and Explain",
    "Listen, Explain, and Align", "Perceived Responsiveness", "Decision Acceptance",
    "Perceived Responsiveness * Listen and Explain", "Perceived Responsiveness * Listen, Explain, and Align",
    "Decision Acceptance * Listen and Explain", "Decision Acceptance * Listen, Explain, and Align"
  ),
  star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
  notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
  type = "html", out = "OA2 Table 2.htm"
)


model4_1 <- model4
model5_1 <- model5


### Study 2 Analysis

## OA3 Figure 2

model1 <- lm(mayor_blame ~ consultation,
  na.action = na.omit,
  data = blame_2
)

eff1 <- effect("consultation", model1, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))

# Extract by-group significance levels (comparison with control group mean)
p.values <- summary(model1)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif[c(1)] <- "' '" # Delete intercept coefficients

# Graph
figure_1 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), shape = 18, colour = ext_538[1]) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, hjust = -0.15, colour = ext_538[1], show.legend = FALSE, parse = TRUE
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  theme(legend.title = element_blank()) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave("OA3 Figure 2.png", width = 5, height = 5)


## OA3 Figure 1

model2 <- lm(mayor_blame ~ responsiveness * consultation,
  na.action = na.omit,
  data = blame_2
)

predictions <- ggpredict(model2,
  terms = c(
    "responsiveness",
    "consultation[Control, Listen/Explain, Listen/Explain/Align]"
  ),
  ci.lvl = 0.835
)


p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed", "dotted")) +
  scale_colour_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  labs(
    title = "Panel A: Perceived Responsiveness",
    x = "Perceived Responsiveness",
    y = "Blame Attribution",
    colour = "Treatment",
    linetype = "Treatment",
    fill = "Treatment"
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(ylim = c(1.8, 4.2))



model3 <- lm(mayor_blame ~ decision_acceptance * consultation,
  na.action = na.omit,
  data = blame_2
)

predictions <- ggpredict(model3,
  terms = c(
    "decision_acceptance",
    "consultation[Control, Listen/Explain, Listen/Explain/Align]]"
  ),
  ci.lvl = 0.835
)

p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("dotted", "dashed", "dotted")) +
  scale_colour_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[1], ext_538[2], ext_538[3])) +
  labs(
    title = "Panel B: Decision Acceptance",
    x = "Decision Acceptance",
    y = "Blame Attribution",
    colour = "Treatment",
    linetype = "Treatment",
    fill = "Treatment"
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(ylim = c(1.8, 4.2))

Appendix_Figure_1 <- ggarrange(p1, p2, nrow = 1, common.legend = TRUE, legend = "bottom")
ggsave(file = "OA3 Figure 1.png", Appendix_Figure_1, width = 9, height = 4)



# OA4 Figure 5

# Regression
model4 <- lm(mayor_blame ~ pro_policy * consultation,
  na.action = na.omit,
  data = blame_2
)

# Generate by group means and confidence intervals
eff0 <- effect("pro_policy * consultation", model4, typical = "mean", se = c(level = .835))
eff0r <- cbind(eff0$x, fit = eff0$fit, lower = eff0$lower, higher = eff0$upper)
eff0r <- eff0r[order(eff0r$pro_policy, eff0r$consultation), ]
rownames(eff0r) <- NULL
eff0r$treat <- as.numeric(rownames(eff0r))
eff0r$consultation <- factor(x = eff0r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff0r$pro_policy <- factor(x = eff0r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff0r <- eff0r[with(eff0r, order(pro_policy, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model4)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(pro_policy, ref = "Pro-Policy")
* consultation,
na.action = na.omit,
data = blame_2
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signif <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph
ggplot(eff0r, aes(
  x = consultation,
  y = fit,
  position = pro_policy, colour = pro_policy, shape = pro_policy
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave("OA4 Figure 5.png", width = 5, height = 5)



# Figure 4 (Panel A)

# Regression
model5 <- lm(mayor_blame ~ wall * consultation,
  na.action = na.omit,
  data = blame_2
)

# Generate by group means and confidence intervals
eff0 <- effect("wall * consultation", model5, typical = "mean", se = c(level = .835))
eff0r <- cbind(eff0$x, fit = eff0$fit, lower = eff0$lower, higher = eff0$upper)
eff0r <- eff0r[order(eff0r$wall, eff0r$consultation), ]
rownames(eff0r) <- NULL
eff0r$treat <- as.numeric(rownames(eff0r))
eff0r$consultation <- factor(x = eff0r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff0r$wall <- factor(x = eff0r$wall, levels = c(
  "Changing Course",
  "Pushing Forward"
))
eff0r <- eff0r[with(eff0r, order(wall, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model5)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(wall, ref = "Pushing Forward")
* consultation,
na.action = na.omit,
data = blame_2
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signifa <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signifa[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph

figure_4a <- ggplot(eff0r, aes(
  x = consultation,
  y = fit,
  position = wall, colour = wall, shape = wall
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifa)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel A: Adaptation Effects", x = "\nConsultation", y = "Blame Attribution") +
  coord_cartesian(ylim = c(2.25, 3.25)) +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(
    legend.position = c(.99, .925),
    legend.justification = c("right", "top"),
    legend.box.just = "right",
    legend.margin = margin(1, 1, 1, 1),
    legend.spacing.y = unit(0, "mm"),
    panel.border = element_rect(colour = "grey", fill = NA),
    legend.title = element_text(size = 10),
    legend.background = element_blank(),
    legend.box.background = element_rect(colour = "grey"),
    strip.background = element_rect(fill = ggplot2::alpha(ext_538[1], .025))
  )


# Regression
# Figure 4 (Panel B)

# Regression
model6 <- lm(mayor_blame ~ female_politician * consultation,
  na.action = na.omit,
  data = blame_2
)

# Generate by group means and confidence intervals
eff0 <- effect("female_politician * consultation", model6, typical = "mean", se = c(level = .835))
eff0r <- cbind(eff0$x, fit = eff0$fit, lower = eff0$lower, higher = eff0$upper)
eff0r <- eff0r[order(eff0r$female_politician, eff0r$consultation), ]
rownames(eff0r) <- NULL
eff0r$treat <- as.numeric(rownames(eff0r))
eff0r$consultation <- factor(x = eff0r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff0r$female_politician <- factor(x = eff0r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff0r <- eff0r[with(eff0r, order(female_politician, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model6)$coefficients[2:4, 4] # Extract direct effect p-values from original model

p.values2 <- lm(mayor_blame ~ relevel(female_politician, ref = "Female Politician")
* consultation,
na.action = na.omit,
data = blame_2
) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:4, 4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2)
p.signifb <- symnum(p.values,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signifb[c(1, 4)] <- "' '" # Delete intercept coefficients

# Graph

figure_4b <- ggplot(eff0r, aes(
  x = consultation,
  y = fit,
  position = female_politician, colour = female_politician, shape = female_politician
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifb)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel B: Gender Effects", x = "\nConsultation", y = "Blame Attribution") +
  coord_cartesian(ylim = c(2.25, 3.25)) +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(
    legend.position = c(.99, .925),
    legend.justification = c("right", "top"),
    legend.box.just = "right",
    legend.margin = margin(1, 1, 1, 1),
    legend.spacing.y = unit(0, "mm"),
    panel.border = element_rect(colour = "grey", fill = NA),
    legend.title = element_text(size = 10),
    legend.background = element_blank(),
    legend.box.background = element_rect(colour = "grey"),
    strip.background = element_rect(fill = ggplot2::alpha(ext_538[1], .025))
  )

Figure_4 <- ggarrange(figure_4a, figure_4b, nrow = 1)
ggsave(file = "Figure 4.png", Figure_4, width = 9, height = 4)

# Regression

# Regression
model6b <- lm(mayor_blame ~ female_politician * sexism * consultation,
  na.action = na.omit,
  data = blame_2
)

xrange <- quantile(blame_2$sexism, probs = c(.05, .95))


# Control-Consultation Comparisons
predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Control]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Control` = ""))
p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Control Group",
    x = "Sexism",
    y = "Blame Attribution",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(2.25, 3.25))

predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Listen/Explain]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Listen/Explain` = ""))
p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Listen/Explain Treatment",
    x = "Sexism",
    y = " ",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(2.25, 3.25))


predictions <- ggpredict(model6b,
  terms = c(
    "sexism",
    "female_politician [Male Politician, Female Politician]",
    "consultation [Listen/Explain/Align]"
  ),
  ci.lvl = 0.835
)

facet_label <- as_labeller(c(`Listen/Explain/Align` = ""))
p3 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
  geom_line(aes(linetype = group)) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025))) +
  scale_linetype_manual(values = c("solid", "dashed")) +
  scale_colour_manual(values = c(ext_538[2], ext_538[3])) +
  scale_fill_manual(values = c(ext_538[2], ext_538[3])) +
  facet_wrap(~facet, labeller = "facet_label") +
  labs(
    title = "Listen/Explain/Align Treatment",
    x = "Sexism",
    y = " ",
    colour = " ",
    linetype = " ",
    fill = " "
  ) +
  guides(fill = "none", color = guide_legend(override.aes = list(fill = NA))) +
  coord_cartesian(xlim = xrange, ylim = c(2.25, 3.25))


Appendix_figure_3 <- ggarrange(p1, p2, p3, nrow = 1)

ggsave(file = "OA3 Figure 3.png", Appendix_figure_3, width = 10, height = 4)


## OA4 Figure 6
r1 <- mayor_blame_drop ~ consultation
r2 <- mayor_blame_death ~ consultation

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame_2
)
summary(fitsur)

restriction <- "rdrop_(Intercept)- rdeath_(Intercept)"
linearHypothesis(fitsur, restriction, test = "Chisq")

t.test(blame_2$mayor_blame_drop, blame_2$mayor_blame_death)
mean(blame_2$mayor_blame_drop)
mean(blame_2$mayor_blame_death)

# Figure

model7a <- lm(mayor_blame_drop ~ consultation,
  na.action = na.omit,
  data = blame_2
)

eff1 <- effect("consultation", model7a, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$group <- "Town's Destruction"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model7a)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients



model7b <- lm(mayor_blame_death ~ consultation,
  na.action = na.omit,
  data = blame_2
)

eff2 <- effect("consultation", model7b, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model7b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients

# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signif <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)


ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  theme_hc() +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))

ggsave("OA4 Figure 6.png", width = 5, height = 5)


# OA4 Figure 7

r1 <- mayor_blame_drop ~ consultation * pro_policy
r2 <- mayor_blame_death ~ consultation * pro_policy

fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame_2
)
summary(fitsur)

restriction <- "rdrop_pro_policyPro-Policy- rdeath_pro_policyPro-Policy"
linearHypothesis(fitsur, restriction, test = "Chisq")


model8a <- lm(mayor_blame_drop ~ consultation * pro_policy,
  na.action = na.omit,
  data = blame_2
)

eff1 <- effect("consultation * pro_policy", model8a, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$pro_policy <- factor(x = eff1r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff1r$group <- "Town's Destruction"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model8a)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_drop ~ consultation * relevel(pro_policy, ref = "Pro-Policy"),
  na.action = na.omit,
  data = blame_2
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values1 <- c(p.values1, p.valuesalt)
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif1[c(1, 4)] <- "' '" # Delete intercept coefficients


model8b <- lm(mayor_blame_death ~ consultation * pro_policy,
  na.action = na.omit,
  data = blame_2
)

eff2 <- effect("consultation * pro_policy", model8b, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$pro_policy <- factor(x = eff2r$pro_policy, levels = c(
  "Anti-Policy",
  "Pro-Policy"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model8b)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_death ~ consultation * relevel(pro_policy, ref = "Pro-Policy"),
  na.action = na.omit,
  data = blame_2
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values2 <- c(p.values2, p.valuesalt)
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif2[c(1, 4)] <- "' '" # Delete intercept coefficients


# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signifa <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)


p1 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signifa)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel A: Policy Stance", x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  facet_grid(~pro_policy) +
  scale_y_continuous(breaks = c(2.2, 2.6, 3, 3.4)) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))


# Graph

r1 <- mayor_blame_drop ~ consultation * female_politician
r2 <- mayor_blame_death ~ consultation * female_politician

blame_2_simple_labels <- read_csv("blame_2.csv")

blame_2_simple_labels <- blame_2_simple_labels %>%
  mutate(female_politician = factor(female_politician,
    levels = 0:1,
    labels = c(
      "Male",
      "Female"
    )
  ))

blame_2_simple_labels <- blame_2_simple_labels %>%
  mutate(consultation = factor(consultation, levels = 1:3))


fitsur <- systemfit(list(rdrop = r1, rdeath = r2),
  data = blame_2_simple_labels
)
summary(fitsur)

restriction <- "rdrop_female_politicianFemale- rdeath_female_politicianFemale"
linearHypothesis(fitsur, restriction, test = "Chisq")


# Graph

model8c <- lm(mayor_blame_drop ~ consultation * female_politician,
  na.action = na.omit,
  data = blame_2
)

eff1 <- effect("consultation * female_politician", model8c, typical = "mean", se = c(level = .835))
eff1r <- cbind(eff1$x, fit = eff1$fit, lower = eff1$lower, higher = eff1$upper)
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r))
eff1r$consultation <- factor(x = eff1r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff1r$female_politician <- factor(x = eff1r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff1r$group <- "Town's Destruction"

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model8c)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif1[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_drop ~ consultation * relevel(female_politician, ref = "Female Politician"),
  na.action = na.omit,
  data = blame_2
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values1 <- c(p.values1, p.valuesalt)
p.signif1 <- symnum(p.values1,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif1[c(1, 4)] <- "' '" # Delete intercept coefficients


model8c <- lm(mayor_blame_death ~ consultation * female_politician,
  na.action = na.omit,
  data = blame_2
)

eff2 <- effect("consultation * female_politician", model8c, typical = "mean", se = c(level = .835))
eff2r <- cbind(eff2$x, fit = eff2$fit, lower = eff2$lower, higher = eff2$upper)
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r))
eff2r$consultation <- factor(x = eff2r$consultation, levels = c(
  "Control",
  "Listen/Explain",
  "Listen/Explain/Align"
))
eff2r$female_politician <- factor(x = eff2r$female_politician, levels = c(
  "Male Politician",
  "Female Politician"
))
eff2r$group <- "Deaths"

# Extract by-group significance levels (comparison with control group mean)
p.values2 <- summary(model8c)$coefficients[1:3, 4] # Extract direct effect p-values from original model
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)
p.signif2[c(1)] <- "' '" # Delete intercept coefficients


p.valuesalt <- lm(mayor_blame_death ~ consultation * relevel(female_politician, ref = "Female Politician"),
  na.action = na.omit,
  data = blame_2
) # Model with alternative factor baseline
p.valuesalt <- summary(p.valuesalt)$coefficients[1:3, 4] # Extract direct effect p-values

p.values2 <- c(p.values2, p.valuesalt)
p.signif2 <- symnum(p.values2,
  corr = FALSE,
  na = FALSE,
  cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
  symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '")
)

p.signif2[c(1, 4)] <- "' '" # Delete intercept coefficients


# Combine, plus prep groups
p.values <- c(p.values1, p.values2)
p.signif <- c(p.signif1, p.signif2)
eff1r <- rbind(eff1r, eff2r)

p2 <- ggplot(eff1r, aes(
  x = consultation,
  y = fit,
  position = group, colour = group, shape = group
)) +
  geom_pointrange(aes(ymin = lower, ymax = higher), position = position_dodge(width = 0.2)) +
  geom_text(aes(label = paste(round(fit, digits = 2), "^", p.signif)),
    size = 3, show.legend = FALSE, parse = TRUE, position = position_dodge(width = .9)
  ) +
  labs(title = "Panel B: Politician Gender", x = "\nConsultation", y = "Blame Attribution") +
  scale_shape_manual(values = c(18, 1)) +
  labs(colour = "Treatment:", shape = "Treatment:") +
  scale_colour_manual(values = c(ext_538[1], ext_538[4])) +
  theme_hc() +
  facet_grid(~female_politician) +
  theme(strip.background = element_rect(fill = ggplot2::alpha("gray", .025)))


OA4_Figure_7 <- ggarrange(p1, p2, nrow = 2, common.legend = TRUE, legend = "bottom")
ggsave(file = "OA4 Figure 7.png", OA4_Figure_7, width = 9, height = 10)



## Tables

stargazer(model1, model5, model6, model6b,
  dep.var.labels = c("Blame Attributed to Mayor"),
  single.row = TRUE, no.space = TRUE,
  order = c(4, 5, 1, 2, 3, 6, 7, 9, 10),
  covariate.labels = c(
    "<b>Consultation (baseline: None)</b> <br> Listen and Explain",
    "Listen, Explain, and Align", "Mayor Stays the Course", "Female Politician", "Sexism",
    "Mayor Stays the Course * Listen and Explain", "Mayor Stays the Course * Listen, Explain, and Align",
    "Female Politician * Listen and Explain", "Female Politician * Listen, Explain, and Align",
    "Sexism * Female Politician", "Sexism * Listen and Explain", "Sexism * Listen, Explain, and Align",
    "Sexism * Female Politician * Listen and Explain", "Sexism * Female Politician * Listen, Explain, and Align"
  ),
  star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
  notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
  type = "html", out = "OA2 Table 3.htm"
)


stargazer(model2, model3,
  dep.var.labels = c("Blame Attributed to Mayor"),
  single.row = TRUE, no.space = TRUE,
  order = c(3, 4, 1, 2),
  covariate.labels = c(
    "<b>Consultation (baseline: None)</b> <br> Listen and Explain",
    "Listen, Explain, and Align", "Perceived Responsiveness", "Decision Acceptance",
    "Perceived Responsiveness * Listen and Explain", "Perceived Responsiveness * Listen, Explain, and Align",
    "Decision Acceptance * Listen and Explain", "Decision Acceptance * Listen, Explain, and Align"
  ),
  star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
  notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
  type = "html", out = "OA2 Table 4.htm"
)

stargazer(model4_1, model4, model5_1,
  dep.var.labels = c("Blame Attributed to Mayor"),
  order = c(3, 4, 1, 2),
  covariate.labels = c(
    "<b>Consultation (baseline: None)</b> <br> Listen and Explain",
    "Listen, Explain, and Align", "Pro-Policy", "Co-Partisan",
    "Pro-Policy * Listen and Explain", "Pro-Policy * Listen, Explain, and Align",
    "Co-Partisan * Listen and Explain", "Co-Partisan * Listen, Explain, and Align"
  ),
  single.row = TRUE, no.space = TRUE,
  notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
  type = "html", out = "OA4 Table 1.htm"
)



### Demographics Table

# Prepare categorical variables/labels for tables

blame$education_cat <- cut(blame$education,
  breaks = c(-Inf, 2, 3, 5, Inf),
  labels = c(1, 2, 3, 4)
)
blame$income_cat <- blame$income

blame <- blame %>%
  mutate(income_cat = factor(income_cat,
    levels = 1:12,
    labels = c(
      "<10k",
      "=>10k, <20k",
      "=>20k, <30k",
      "=>30k, <40k",
      "=>40k, <50k",
      "=>50k, <60k",
      "=>60k, <70k",
      "=>70k, <80k",
      "=>80k, <90k",
      "=>90k, <100k",
      "=>100k, <150k",
      "150k+"
    )
  ))


blame_2$education <- gsub("'", "", blame_2$education) # Remove apostrophes to simplify recode
blame_2$education_cat <- dplyr::recode(blame_2$education,
  "Less than high school degree" = 1,
  "High school graduate (high school diploma or equivalent including GED)" = 1,
  "Some college but no degree" = 2,
  "Associate degree in college (2-year)" = 3,
  "Bachelors degree in college (4-year)" = 3,
  "Masters degree" = 4,
  "Doctoral degree" = 4,
  "Professional degree (JD, MD)" = 4
)

blame_2$income_cat <- dplyr::recode(blame_2$income,
  "Less than $10,000" = 1,
  "$10,000 to $19,999" = 2,
  "$20,000 to $29,999" = 3,
  "$30,000 to $39,999" = 4,
  "$40,000 to $49,999" = 5,
  "$50,000 to $59,999" = 6,
  "$60,000 to $69,999" = 7,
  "$70,000 to $79,999" = 8,
  "$80,000 to $89,999" = 9,
  "$90,000 to $99,999" = 10,
  "$100,000 to $149,999" = 11,
  "$150,000 or more" = 12
)
blame_2 <- blame_2 %>%
  mutate(income_cat = factor(income_cat,
    levels = 1:12,
    labels = c(
      "<10k",
      "=>10k, <20k",
      "=>20k, <30k",
      "=>30k, <40k",
      "=>40k, <50k",
      "=>50k, <60k",
      "=>60k, <70k",
      "=>70k, <80k",
      "=>80k, <90k",
      "=>90k, <100k",
      "=>100k, <150k",
      "150k+"
    )
  ))


blame <- blame %>%
  mutate(region = factor(region,
    levels = 1:4,
    labels = c(
      "Northeast",
      "Midwest",
      "West",
      "South"
    )
  ))

blame <- blame %>%
  mutate(age = factor(age,
    levels = 2:7,
    labels = c(
      "18-24",
      "25-34",
      "35-44",
      "45-54",
      "55-64",
      "65+"
    )
  ))

blame <- blame %>%
  mutate(female = factor(female,
    levels = 0:1,
    labels = c(
      "Male",
      "Female"
    )
  ))

blame <- blame %>%
  mutate(education_cat = factor(education_cat,
    levels = 1:4,
    labels = c(
      "Highschool or Less",
      "Some College",
      "College Degree",
      "Post-grad Degree"
    )
  ))

blame_2 <- blame_2 %>%
  mutate(education_cat = factor(education_cat,
    levels = 1:4,
    labels = c(
      "Highschool or Less",
      "Some College",
      "College Degree",
      "Post-grad Degree"
    )
  ))

blame$race_cat[which(is.na(blame$race_cat))] <- "Prefer not to say"

blame$pro_policy <- as.character(blame$pro_policy)
blame$pro_policy[which(is.na(blame$pro_policy))] <- "Neither"

blame_2$pro_policy <- as.character(blame_2$pro_policy)
blame_2$pro_policy[which(is.na(blame_2$pro_policy))] <- "Neither"

# Combine datasets
myvars <- c(
  "female", "region", "race_cat", "age", "income_cat", "education_cat", "pid_3", "pid_str",
  "mayor_blame_drop", "mayor_blame_death", "mayor_blame", "pro_policy",
  "responsiveness", "decision_acceptance", "sexism"
)

blame_1_dem <- blame[myvars]
blame_1_dem$study <- 1
blame_2_dem <- blame_2[myvars]
blame_2_dem$study <- 2

blame_combined <- rbind(blame_1_dem, blame_2_dem)

# Demographic Table (both full sample and used sample) - see https://cran.r-project.org/web/packages/table1/vignettes/table1-examples.html
labels <- list(
  variables = list(
    female = "Sex",
    region = "Region",
    race_cat = "Race",
    age = "Age Bracket",
    income_cat = "Income Bracket",
    education_cat = "Education",
    pid_3 = "Partisan ID",
    pid_str = "Partisan Strength"
  ),
  groups = list("", "Study Number")
)

strata <- c(list(Total = blame_combined), split(blame_combined, blame_combined$study)) # Set order

dem_table <- table1(strata, labels, groupspan = c(1, 2))
knitr::kable(dem_table, "html") %>%
  kable_styling("condensed") %>%
  cat(., file = "OA1 Table 2.html")

# Variables table
labels2 <- list(
  variables = list(
    pro_policy = "In Favour of Policy",
    mayor_blame_drop = "Blame for Material Damage/Drop in Beds",
    mayor_blame_death = "Blame for Deaths",
    mayor_blame = "Average Blame",
    responsiveness = "Perceived Responsiveness",
    decision_acceptance = "Decision Acceptance",
    sexism = "Hostile Sexism"
  ),
  groups = list("", "Study Number")
)

label(blame_combined$mayor_blame_drop) <- "Blame for Material Damage/Drop in Beds"
label(blame_combined$mayor_blame_death) <- "Blame for Deaths"
label(blame_combined$mayor_blame) <- "Average Blame"
label(blame_combined$pro_policy) <- "Stance on Policy"
label(blame_combined$responsiveness) <- "Perceived Responsiveness"
label(blame_combined$decision_acceptance) <- "Decision Acceptance"
label(blame_combined$sexism) <- "Hostile Sexism"

var_table <- table1(strata, labels2, groupspan = c(1, 2))
save_html(var_table, file = "OA1 Table 3.html")
